hdx package
===========

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   hdx.data
   hdx.facades

Submodules
----------

hdx.hdx\_configuration module
-----------------------------

.. automodule:: hdx.hdx_configuration
   :members:
   :undoc-members:
   :show-inheritance:

hdx.hdx\_locations module
-------------------------

.. automodule:: hdx.hdx_locations
   :members:
   :undoc-members:
   :show-inheritance:

hdx.version module
------------------

.. automodule:: hdx.version
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: hdx
   :members:
   :undoc-members:
   :show-inheritance:
